package controller.listener;

import java.awt.event.MouseEvent;
import javax.swing.event.MouseInputAdapter;
import model.drawables.Circle;
import model.drawables.DashedCircle;
import model.drawables.Point;
import controller.DrawableObjectProcessing;

/**
 * Ein Listener, der Circles durch MouseEvents erzeugt und an ein Objekt, das
 * DrawableObjectProcessing implementiert übergibt.
 * 
 * @author Denis Meyer
 * @author Niels Meyering
 * 
 */
public class CircleListener extends MouseInputAdapter {

	private DrawableObjectProcessing delegate;
	private Point start = null;

	/**
	 * @param delegate
	 */
	public CircleListener(DrawableObjectProcessing delegate) {
		this.delegate = delegate;
	}

	/**
	 * Erzeuge einen neuen Kreis bei den Klick-Koordinaten und übergebe ihn an
	 * das Delegate.
	 * 
	 * @param e
	 */
	public void mouseClicked(MouseEvent e) {
		Point p = new Point(e.getX(), e.getY());

		if (start == null) { // Falls Startpunkt
			start = p;
		} else {
			// Falls Endpunkt: Kreis vom Startpunkt mit neuem Radius
			delegate.processDrawableObject(new Circle(start, Circle.getRadius(
					start, p)));
			start = null;
		}
	}

	/**
	 * Gestrichelten Kreis anzeigen, wenn Startpunkt festgelegt
	 * 
	 * @param e
	 *            MouseEvent
	 */
	public void mouseMoved(MouseEvent e) {
		if (start != null) {
			// Lschen des temporren Objektes
			delegate.clearTemporaryDrawableObject();
			// Zeichnen eines neuen temporren Objektes
			delegate.setTemporaryDrawableObject(new DashedCircle(start, Circle
					.getRadius(start, new Point(e.getX(), e.getY()))));
		}
	}
}
