package controller.listener;

import java.awt.event.MouseEvent;
import javax.swing.event.MouseInputAdapter;
import model.drawables.DashedRectangle;
import model.drawables.Point;
import model.drawables.Rectangle;
import controller.DrawableObjectProcessing;

/**
 * Ein Listener, der Rectangles durch MouseEvents erzeugt und an ein Objekt, das
 * DrawableObjectProcessing implementiert übergibt.
 * 
 * @author Denis Meyer
 * @author Niels Meyering
 * 
 */
public class RectangleListener extends MouseInputAdapter {

	private DrawableObjectProcessing delegate;
	private Point start = null;

	/**
	 * @param delegate
	 */
	public RectangleListener(DrawableObjectProcessing delegate) {
		this.delegate = delegate;
	}

	/**
	 * Erzeuge ein neues Rechteck bei den Klick-Koordinaten und übergebe ihn an
	 * das Delegate.
	 * 
	 * @param e
	 */
	public void mouseClicked(MouseEvent e) {
		Point p = new Point(e.getX(), e.getY());

		if (start == null) { // Falls Startpunkt
			start = p;
		} else {
			// Falls Endpunkt: Rechteck vom Startpunkt ber bis zum Endpunkt
			// erzeugen
			delegate.processDrawableObject(new Rectangle(start, p));
			start = null;
		}
	}

	/**
	 * Gestricheltes Rechteck anzeigen, wenn Startpunkt festgelegt
	 * 
	 * @param e
	 *            MouseEvent
	 */
	public void mouseMoved(MouseEvent e) {
		if (start != null) {
			// Lschen des temporren Objektes
			delegate.clearTemporaryDrawableObject();
			// Zeichnen eines neuen temporren Objektes
			delegate.setTemporaryDrawableObject(new DashedRectangle(start,
					new Point(e.getX(), e.getY())));
		}
	}
}
