package model.drawables;

import java.awt.Graphics;

/**
 * Repräsentiert eine Anti-Aliased Linie
 * 
 * @author Denis Meyer
 * @author Niels Meyering
 * 
 */
public class AntiAliasedLine extends DrawableObject {

	private Point p1, p2; // Anfangs- und Endpunkt

	/**
	 * Konstruktor
	 * 
	 * @param p1
	 *            Punkt 1
	 * @param p2
	 *            Punkt 2
	 */
	public AntiAliasedLine(Point p1, Point p2) {
		this.p1 = p1;
		this.p2 = p2;
	}

	/**
	 * Copy-Konstruktor
	 * 
	 * @param copy
	 *            Original, das kopiert werden soll
	 */

	public AntiAliasedLine(AntiAliasedLine copy) {
		this.p1 = copy.p1;
		this.p2 = copy.p2;
	}

	/**
	 * Paint-Methode der Lineklasse. Zeichnet eine Anti-Aliased Linie
	 * 
	 * @param g
	 *            der Graphikkontext, in den das Objekt gezeichnet werden soll
	 */
	public void paint(Graphics g) {
		g.setPaintMode();
		int x, y, inc_x, inc_y;
		float error, schritt, dx, dy;

		x = p1.getXCoordinate(); // Koordinaten retten
		y = p1.getYCoordinate();

		dy = p2.getYCoordinate() - p1.getYCoordinate(); // Hoehenzuwachs
		dx = p2.getXCoordinate() - p1.getXCoordinate(); // Schrittweite

		if (dx > 0) // Linie nach rechts?
			inc_x = 1; // x inkrementieren
		else
			// Linie nach links
			inc_x = -1; // x dekrementieren

		if (dy > 0) // Linie nach unten?
			inc_y = 1; // y inkrementieren
		else
			// Linie nach oben
			inc_y = -1; // y dekrementieren

		int upOrDown;
		if (Math.abs(dy) < Math.abs(dx)) { // flach nach oben oder unten
			error = 0.0f; // Fehler bestimmen
			schritt = Math.abs(dy) / Math.abs(dx); // Schwelle bestimmen
			while (x != p2.getXCoordinate()) { // Fuer jede x-Koordinate
				upOrDown = (error <= 0) ? -1 : 1;
				if (inc_y < 0) {
					setPixel(x, y, Math.abs(error), g); // setze Pixel mit
					// Grauwert
					setPixel(x, y - upOrDown, 1 - Math.abs(error), g); // setze
					// Pixel
				} else {
					setPixel(x, y, Math.abs(error), g); // setze Pixel mit
					// Grauwert
					setPixel(x, y + upOrDown, 1 - Math.abs(error), g); // setze
					// Pixel
				}
				// mit 1-
				// Grauwert
				x += inc_x; // naechste x-Koordinate
				error = error + schritt; // Fehler aktualisieren
				if (error > 0.5f) { // neue Spalte erreicht?
					y += inc_y; // y-Koord. aktualisieren
					error -= 1; // Fehler aktualisieren
				}
			}
		} else { // steil nach oben oder unten
			error = 0.0f; // Fehler bestimmen
			schritt = Math.abs(dx) / Math.abs(dy); // Schwelle bestimmen
			while (y != p2.getYCoordinate()) { // Fuer jede x-Koordinate
				upOrDown = (error <= 0) ? -1 : 1;
				if (inc_x < 0) {
					setPixel(x, y, Math.abs(error), g); // setze Pixel mit
					// Grauwert
					setPixel(x - upOrDown, y, 1 - Math.abs(error), g); // setze
					// Pixel
				} else {
					setPixel(x, y, Math.abs(error), g); // setze Pixel mit
					// Grauwert
					setPixel(x + upOrDown, y, 1 - Math.abs(error), g); // setze
					// Pixel
				}
				// mit 1-
				// Grauwert
				y += inc_y; // naechste x-Koordinate
				error = error + schritt; // Fehler aktualisieren
				if (error > 0.5f) { // neue Spalte erreicht?
					x += inc_x; // y-Koord. aktualisieren
					error -= 1; // Fehler aktualisieren
				}
			}
		}
		setPixel(x, y, g); // letztes Pixel hier setzen
	}

	/**
	 * Gibt den Startpunkt zurck
	 * 
	 * @return Startpunkt
	 */
	public Point getStartPoint() {
		return p1;
	}

	/**
	 * Gibt den Endpunkt zurck
	 * 
	 * @return Endpunkt
	 */
	public Point getEndPoint() {
		return p2;
	}
}
